@@ -146,7 +146,7 @@ from SCons.Script.SConscript import DefaultEnvironmentCall
 from modulefinder import ModuleFinder as MF
 from SCons.Script import *
 import re
-import hashlib 
+import hashlib
 import tempfile
 import base64
 from itertools import chain
@@ -255,6 +255,7 @@ command += ["mv %%s %%s" %% (s, t) for s,t in zip(stargets, targets)]
 gen = lambda source, target, env, for_signature: command_sig if for_signature else command
 PyScript(targets, sources, CommandGeneratorAction(gen,{}), clean=False)
 """ % (repr(command_sig), repr(command))
+        scons = re.sub("\$", "\$", scons)
 
         arg = " ".join(["in%g=%s" % (n+1, str(s)) for n,s in enumerate(source)])
         arg += " " + " ".join(["out%g=%s" % (n+1, str(s)) for n,s in enumerate(target)])
@@ -264,7 +265,7 @@ PyScript(targets, sources, CommandGeneratorAction(gen,{}), clean=False)
         file = open(exe, 'w')
         comments = "\n".join(["#TARGET\t%s" % s for s in target] + ["#SOURCE\t%s"
             %s for s in source + [exe]])
-        print >>file, "#!/usr/bin/env scons %s %s -f\n%s\n%s" % (vars, arg, comments, scons)
+        print >>file, "#!/bin/bash\n%s\nscons %s %s -f <( cat <<ENDOFSCONS\n%s\nENDOFSCONS\n) $*" % (comments, vars, arg, scons)
         os.chmod(exe, 0755)
         file.close()
 
